#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const Logger = require('@mojaloop/central-services-logger');
const commander_1 = require("commander");
const runResult_1 = require("./runResult");
const types_1 = require("./types");
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const config_1 = require("./config");
const collections_1 = tslib_1.__importDefault(require("./collections"));
const runCollection = async (collection) => {
    const collectionNameFormatted = chalk_1.default.blue(collection.name);
    Logger.info(`  ${chalk_1.default.bold('Running')}: ${collectionNameFormatted}`);
    Logger.info(`  ${chalk_1.default.bold('Description')}: ${collection.description}`);
    Logger.info(`  |`);
    const result = await collection.run();
    Logger.info(`  |`);
    switch (result.type) {
        case runResult_1.RunResultType.SUCCESS: {
            Logger.info(`  ${collectionNameFormatted} ${chalk_1.default.green(`Passed`)}`);
            if (result.warnings.length > 0) {
                Logger.info(`  ${chalk_1.default.yellow('Passed with warnings:')} \n    - ${result.warnings.join('\n    - ')}`);
            }
            break;
        }
        case runResult_1.RunResultType.FAILURE:
            Logger.info(`${collectionNameFormatted} ${chalk_1.default.red(`Failed`)}`);
            if (result.warnings.length > 0) {
                Logger.info(`  ${chalk_1.default.yellow('Failed with warnings:')} \n    - ${result.warnings.join('\n    - ')}`);
            }
            Logger.info(`  ${chalk_1.default.red('Failed with errors:')} \n    - ${result.errors.join('\n    - ')}`);
            break;
    }
};
function makeBootstrapAction(bootstrapType, options) {
    return async () => {
        if (options.fspid) {
            // User has specified an fspId to run
            if (bootstrapType === types_1.BootstrapType.HUB) {
                throw new Error('invalid input. Cannot specify fspId AND hub options');
            }
        }
        // Load the config file
        const config = config_1.loadFromFile(options.config);
        const collections = collections_1.default(bootstrapType, config, options.fspid);
        for (const collection of collections) {
            await runCollection(collection);
        }
    };
}
const program = new commander_1.Command();
program
    .option('-c, --config <path/to/config>', 'bootstrap config file')
    .option('-f, --fspid <fspid>', 'fspid of a participant specifed in the config file. \n\t\t\t\t Use this option to bootstrap only 1 participant at a time', undefined);
program.description('bootstrap all, Hub, DFSPs, PISPs, Parties')
    .action(makeBootstrapAction(types_1.BootstrapType.ALL, program.opts()));
program.command('all')
    .description('bootstrap all, Hub, DFSPs, PISPs, Parties')
    .action(makeBootstrapAction(types_1.BootstrapType.ALL, program.opts()));
program.command('hub')
    .description('set up the Mojaloop hub')
    .action(makeBootstrapAction(types_1.BootstrapType.HUB, program.opts()));
program.command('participants')
    .description('onboard only the participants')
    .action(makeBootstrapAction(types_1.BootstrapType.PARTICIPANTS, program.opts()));
program.command('parties')
    .description('onboard only the parties')
    .action(makeBootstrapAction(types_1.BootstrapType.PARTIES, program.opts()));
program.parseAsync(process.argv);
//# sourceMappingURL=cli.js.map