"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.formatAndValidateConfig = exports.loadFromFile = exports.ConvictConfig = void 0;
const tslib_1 = require("tslib");
const convict_1 = tslib_1.__importDefault(require("convict"));
const path_1 = tslib_1.__importDefault(require("path"));
const json5_1 = tslib_1.__importDefault(require("json5"));
const Logger = require('@mojaloop/central-services-logger');
convict_1.default.addParser({ extension: 'json5', parse: json5_1.default.parse });
exports.ConvictConfig = convict_1.default({
    currency: {
        doc: 'DEPRECATED. Use currencies instead. The currency of the switch',
        format: String,
        default: undefined,
        env: 'CURRENCY'
    },
    currencies: {
        doc: 'A list of currencies to register with the Hub account and DFSP accounts',
        format: (val) => {
            if (!Array.isArray(val)) {
                throw new Error('`currencies` must be an array');
            }
        },
        default: [],
    },
    urls: {
        fspiop: {
            doc: 'Switch endpoint for fspiop(Mojaloop) API. '
                + 'Use this if your mojaloop switch is running behind an API Gateway'
                + 'otherwise use the individual *endpoint definitions below',
            format: '*',
            env: 'FSPIOP_URL',
            default: null
        },
        alsEndpoint: {
            doc: 'Endpoint for the account lookup service (`/parties` and `/participants` resources)',
            format: '*',
            env: 'ALS_URL',
            default: null
        },
        alsAdmin: {
            doc: 'Switch endpoint for ALS Admin API',
            format: '*',
            env: 'ALS_ADMIN_URL',
            default: '0.0.0.0:4004/account-lookup-service-admin'
        },
        centralLedgerAdmin: {
            doc: 'Switch endpoint for the central-ledger admin API',
            format: '*',
            env: 'CENTRAL_LEDGER_ADMIN_URL',
            default: '0.0.0.0:4004/central-ledger'
        },
    },
    applicationUrls: {
        oracle: {
            doc: '[deprecated] Switch endpoint for oracle simulator - used to point the ALS to the oracle sim. Use `oracles` instead',
            format: '*',
            env: 'ORACLE_URL',
            default: '0.0.0.0:4004/oracle-simulator'
        },
    },
    oracles: {
        doc: 'A list of oracles to register',
        format: (val) => {
            if (!Array.isArray(val)) {
                throw new Error('`oracles` must be an array');
            }
        },
        default: []
    },
    participants: {
        doc: 'A list of participants (DFSPs, PISPs), with nested parties',
        format: (val) => {
            if (!Array.isArray(val)) {
                throw new Error('`participants` must be an array');
            }
            //TODO: other validation!
        },
        default: []
    }
});
function loadFromFile(filePath) {
    if (path_1.default.isAbsolute(filePath)) {
        exports.ConvictConfig.loadFile(filePath);
    }
    else {
        exports.ConvictConfig.loadFile(path_1.default.join('./', filePath));
    }
    exports.ConvictConfig.validate({ allowed: 'strict' });
    const resolvedConfig = {
        currency: exports.ConvictConfig.get('currency'),
        currencies: exports.ConvictConfig.get('currencies'),
        urls: exports.ConvictConfig.get('urls'),
        applicationUrls: exports.ConvictConfig.get('applicationUrls'),
        oracles: exports.ConvictConfig.get('oracles'),
        participants: exports.ConvictConfig.get('participants'),
    };
    return formatAndValidateConfig(resolvedConfig);
}
exports.loadFromFile = loadFromFile;
function formatAndValidateConfig(resolvedConfig) {
    let oracles = resolvedConfig.oracles;
    // Validation errors/warnings
    if (resolvedConfig.currency) {
        console.log('resolvedConfig.currency', resolvedConfig.currency);
        Logger.warn('Using deprecated config `currency`. Please use `currencies` instead.');
        // user has specified both options. This is an error
        if (resolvedConfig.currencies.length > 0) {
            throw new Error('Cannot specify both `currency` and `currencies`. Please use updated config');
        }
        // format to be friendly to the new version
        resolvedConfig.currencies = [resolvedConfig.currency];
        // reset so we don't start doing the wrong thing elsewhere
        resolvedConfig.currency = undefined;
    }
    // add a default MSISDN oracle if not specified
    if (!oracles || oracles.length === 0) {
        Logger.warn('Please specify `oracles`. For now, defaulting to a MSISDN oracle');
        oracles = [
            {
                oracleIdType: 'MSISDN',
                endpoint: resolvedConfig.applicationUrls.oracle
            }
        ];
    }
    const strictConfig = {
        oracles,
        ...resolvedConfig
    };
    return strictConfig;
}
exports.formatAndValidateConfig = formatAndValidateConfig;
//# sourceMappingURL=config.js.map